#ifndef _DOWNLOADER_H
#define _DOWNLOADER_H

unsigned long
DownloadFile(const char *filename, const char *url, unsigned long size);

#endif
